==> libreoffice-fresh-sdk-7.5.3-2-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/all_a.js <==
var searchData=
[
  ['j_0',['J',['../namespacecom_1_1sun_1_1star_1_1awt_1_1Key.html#aa6010a052250e93302264bdd36271d88',1,'com::sun::star::awt::Key']]],
  ['january_1',['JANUARY',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#a5cf0296928101ce2b8d17bebb5e73c90',1,'com::sun::star::i18n::Months']]],
  ['japanese_2',['Japanese',['../servicecom_1_1sun_1_1star_1_1chart2_1_1CandleStickChartType.html#a2cad0926393f307b8b4962ffde9bbee4',1,'com::sun::star::chart2::CandleStickChartType']]],
  ['java_3',['Java',['../servicecom_1_1sun_1_1star_1_1loader_1_1Java.html',1,'com::sun::star::loader']]],
  ['java_4',['JAVA',['../namespacecom_1_1sun_1_1star_1_1bridge_1_1ModelDependent.html#a135a03e8044b16fb22bc1c7633e7c658',1,'com::sun::star::bridge::ModelDependent']]],
  ['java_2eidl_5',['Java.idl',['../Java_8idl.html',1,'']]],
  ['java2_6',['Java2',['../servicecom_1_1sun_1_1star_1_1loader_1_1Java2.html',1,'com::sun::star::loader']]],
  ['java2_2eidl_7',['Java2.idl',['../Java2_8idl.html',1,'']]],
  ['javadisabledexception_8',['JavaDisabledException',['../exceptioncom_1_1sun_1_1star_1_1java_1_1JavaDisabledException.html',1,'com::sun::star::java']]],
  ['javadisabledexception_2eidl_9',['JavaDisabledException.idl',['../JavaDisabledException_8idl.html',1,'']]],
  ['javadriverclass_10',['JavaDriverClass',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1JDBCConnectionProperties.html#abdc08b85c582f65f578e62cd9e747bad',1,'com::sun::star::sdbc::JDBCConnectionProperties']]],
  ['javadriverclasspath_11',['JavaDriverClassPath',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1JDBCConnectionProperties.html#afa6ea96eef4856627c8fef22aaa92d22',1,'com::sun::star::sdbc::JDBCConnectionProperties']]],
  ['javainitializationexception_12',['JavaInitializationException',['../exceptioncom_1_1sun_1_1star_1_1java_1_1JavaInitializationException.html',1,'com::sun::star::java']]],
  ['javainitializationexception_2eidl_13',['JavaInitializationException.idl',['../JavaInitializationException_8idl.html',1,'']]],
  ['javanotconfiguredexception_14',['JavaNotConfiguredException',['../exceptioncom_1_1sun_1_1star_1_1java_1_1JavaNotConfiguredException.html',1,'com::sun::star::java']]],
  ['javanotconfiguredexception_2eidl_15',['JavaNotConfiguredException.idl',['../JavaNotConfiguredException_8idl.html',1,'']]],
  ['javanotfoundexception_16',['JavaNotFoundException',['../exceptioncom_1_1sun_1_1star_1_1java_1_1JavaNotFoundException.html',1,'com::sun::star::java']]],
  ['javanotfoundexception_2eidl_17',['JavaNotFoundException.idl',['../JavaNotFoundException_8idl.html',1,'']]],
  ['javascript_18',['JavaScript',['../servicecom_1_1sun_1_1star_1_1script_1_1JavaScript.html',1,'com::sun::star::script']]],
  ['javascript_2eidl_19',['JavaScript.idl',['../JavaScript_8idl.html',1,'']]],
  ['javavirtualmachine_20',['JavaVirtualMachine',['../servicecom_1_1sun_1_1star_1_1java_1_1JavaVirtualMachine.html',1,'com::sun::star::java']]],
  ['javavirtualmachine_2eidl_21',['JavaVirtualMachine.idl',['../JavaVirtualMachine_8idl.html',1,'']]],
  ['javavmcreationfailureexception_22',['JavaVMCreationFailureException',['../exceptioncom_1_1sun_1_1star_1_1java_1_1JavaVMCreationFailureException.html',1,'com::sun::star::java']]],
  ['javavmcreationfailureexception_2eidl_23',['JavaVMCreationFailureException.idl',['../JavaVMCreationFailureException_8idl.html',1,'']]],
  ['jdbcconnectionproperties_24',['JDBCConnectionProperties',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1JDBCConnectionProperties.html',1,'com::sun::star::sdbc']]],
  ['jdbcconnectionproperties_2eidl_25',['JDBCConnectionProperties.idl',['../JDBCConnectionProperties_8idl.html',1,'']]],
  ['job_26',['Job',['../servicecom_1_1sun_1_1star_1_1task_1_1Job.html',1,'com::sun::star::task']]],
  ['job_2eidl_27',['Job.idl',['../Job_8idl.html',1,'']]],
  ['job_5faborted_28',['JOB_ABORTED',['../namespacecom_1_1sun_1_1star_1_1view.html#ad9b0afaffefc166344fd9575516b6626ad325c05e799526434df0446c1bfa1688',1,'com::sun::star::view']]],
  ['job_5fcompleted_29',['JOB_COMPLETED',['../namespacecom_1_1sun_1_1star_1_1view.html#ad9b0afaffefc166344fd9575516b6626a53c0e140b74182a89eea8096b1a51f16',1,'com::sun::star::view']]],
  ['job_5ffailed_30',['JOB_FAILED',['../namespacecom_1_1sun_1_1star_1_1view.html#ad9b0afaffefc166344fd9575516b6626abb2336dc05d82d17eb6f426a7d3242ae',1,'com::sun::star::view']]],
  ['job_5fspooled_31',['JOB_SPOOLED',['../namespacecom_1_1sun_1_1star_1_1view.html#ad9b0afaffefc166344fd9575516b6626adc1230e9b40f225f330421cb85f48e28',1,'com::sun::star::view']]],
  ['job_5fspooling_5ffailed_32',['JOB_SPOOLING_FAILED',['../namespacecom_1_1sun_1_1star_1_1view.html#ad9b0afaffefc166344fd9575516b6626a50a12e42e7a41dbad564813f1634f919',1,'com::sun::star::view']]],
  ['job_5fstarted_33',['JOB_STARTED',['../namespacecom_1_1sun_1_1star_1_1view.html#ad9b0afaffefc166344fd9575516b6626a5b34428f295a0d6b980f7d3d809d2c41',1,'com::sun::star::view']]],
  ['jobexecutor_34',['JobExecutor',['../servicecom_1_1sun_1_1star_1_1task_1_1JobExecutor.html',1,'com::sun::star::task']]],
  ['jobexecutor_2eidl_35',['JobExecutor.idl',['../JobExecutor_8idl.html',1,'']]],
  ['jobfinished_36',['jobFinished',['../interfacecom_1_1sun_1_1star_1_1task_1_1XJobListener.html#ab0c696543c8a005d3ca99c3785f845c4',1,'com::sun::star::task::XJobListener']]],
  ['jobmanager_37',['JobManager',['../servicecom_1_1sun_1_1star_1_1util_1_1JobManager.html',1,'com::sun::star::util']]],
  ['jobmanager_2eidl_38',['JobManager.idl',['../JobManager_8idl.html',1,'']]],
  ['jobname_39',['JobName',['../servicecom_1_1sun_1_1star_1_1view_1_1PrintOptions.html#a896deaa5ee4ac22bd1c8b5b8db37acf1',1,'com::sun::star::view::PrintOptions']]],
  ['jointype_40',['JoinType',['../structcom_1_1sun_1_1star_1_1rendering_1_1StrokeAttributes.html#af92b960dfbc8558928096e5b2076117c',1,'com::sun::star::rendering::StrokeAttributes']]],
  ['journal_41',['JOURNAL',['../namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a76c72d9a192bb0601aa1f27013fad3fd',1,'com::sun::star::text::BibliographyDataType::JOURNAL()'],['../namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a76c72d9a192bb0601aa1f27013fad3fd',1,'com::sun::star::text::BibliographyDataField::JOURNAL()']]],
  ['july_42',['JULY',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#aae7c7cc5b45c941aade847449d8355a2',1,'com::sun::star::i18n::Months']]],
  ['jumpedit_43',['JumpEdit',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1JumpEdit.html',1,'com::sun::star::text::textfield']]],
  ['jumpedit_2eidl_44',['JumpEdit.idl',['../JumpEdit_8idl.html',1,'']]],
  ['jumplist_45',['JumpList',['../servicecom_1_1sun_1_1star_1_1system_1_1windows_1_1JumpList.html',1,'com::sun::star::system::windows']]],
  ['jumplist_2eidl_46',['JumpList.idl',['../JumpList_8idl.html',1,'']]],
  ['jumplistitem_47',['JumpListItem',['../structcom_1_1sun_1_1star_1_1system_1_1windows_1_1JumpListItem.html',1,'com::sun::star::system::windows']]],
  ['jumplistitem_2eidl_48',['JumpListItem.idl',['../JumpListItem_8idl.html',1,'']]],
  ['jumpmark_49',['JumpMark',['../servicecom_1_1sun_1_1star_1_1document_1_1MediaDescriptor.html#a51b2490ba24ae76328c7637f379d8a69',1,'com::sun::star::document::MediaDescriptor']]],
  ['jumptoendofpage_50',['jumpToEndOfPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a476bbce6722fc804b8a67a6d7c4737cb',1,'com::sun::star::text::XPageCursor']]],
  ['jumptofirstpage_51',['jumpToFirstPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a35805ada8e62b68af3548c92d9239fc3',1,'com::sun::star::text::XPageCursor']]],
  ['jumptofurthest_52',['jumpToFurthest',['../interfacecom_1_1sun_1_1star_1_1io_1_1XMarkableStream.html#a0dba23daeafaaf331c5e8cabba583645',1,'com::sun::star::io::XMarkableStream']]],
  ['jumptolastpage_53',['jumpToLastPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a4f09bc833da25f1b6bdf50c27a707e2e',1,'com::sun::star::text::XPageCursor']]],
  ['jumptomark_54',['jumpToMark',['../interfacecom_1_1sun_1_1star_1_1io_1_1XMarkableStream.html#a5076d3fa091ca2a5616176f8e89e0e28',1,'com::sun::star::io::XMarkableStream']]],
  ['jumptonextpage_55',['jumpToNextPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a660dc90441fbc7a6af395112cfd11221',1,'com::sun::star::text::XPageCursor']]],
  ['jumptopage_56',['jumpToPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a909c766dbfe0e7e3e9c71d60f4ad4a36',1,'com::sun::star::text::XPageCursor']]],
  ['jumptopreviouspage_57',['jumpToPreviousPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#aaa932a448992229905f5d5c47e91c830',1,'com::sun::star::text::XPageCursor']]],
  ['jumptostartofpage_58',['jumpToStartOfPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a5c638004a9259895725d2cf920f3a587',1,'com::sun::star::text::XPageCursor']]],
  ['june_59',['JUNE',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#af314dbaf560683281ea205a8e8726e7e',1,'com::sun::star::i18n::Months']]],
  ['justify_60',['justify',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XTextLayout.html#afa630bace2ac1ee7acc044d589e99eb6',1,'com::sun::star::rendering::XTextLayout']]]
];

==> libreoffice-fresh-sdk-7.5.5-1-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/all_a.js <==
var searchData=
[
  ['j_0',['J',['../namespacecom_1_1sun_1_1star_1_1awt_1_1Key.html#aa6010a052250e93302264bdd36271d88',1,'com::sun::star::awt::Key']]],
  ['january_1',['JANUARY',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#a5cf0296928101ce2b8d17bebb5e73c90',1,'com::sun::star::i18n::Months']]],
  ['japanese_2',['Japanese',['../servicecom_1_1sun_1_1star_1_1chart2_1_1CandleStickChartType.html#a2cad0926393f307b8b4962ffde9bbee4',1,'com::sun::star::chart2::CandleStickChartType']]],
  ['java_3',['Java',['../servicecom_1_1sun_1_1star_1_1loader_1_1Java.html',1,'com::sun::star::loader']]],
  ['java_4',['JAVA',['../namespacecom_1_1sun_1_1star_1_1bridge_1_1ModelDependent.html#a135a03e8044b16fb22bc1c7633e7c658',1,'com::sun::star::bridge::ModelDependent']]],
  ['java_2eidl_5',['Java.idl',['../Java_8idl.html',1,'']]],
  ['java2_6',['Java2',['../servicecom_1_1sun_1_1star_1_1loader_1_1Java2.html',1,'com::sun::star::loader']]],
  ['java2_2eidl_7',['Java2.idl',['../Java2_8idl.html',1,'']]],
  ['javadisabledexception_8',['JavaDisabledException',['../exceptioncom_1_1sun_1_1star_1_1java_1_1JavaDisabledException.html',1,'com::sun::star::java']]],
  ['javadisabledexception_2eidl_9',['JavaDisabledException.idl',['../JavaDisabledException_8idl.html',1,'']]],
  ['javadriverclass_10',['JavaDriverClass',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1JDBCConnectionProperties.html#abdc08b85c582f65f578e62cd9e747bad',1,'com::sun::star::sdbc::JDBCConnectionProperties']]],
  ['javadriverclasspath_11',['JavaDriverClassPath',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1JDBCConnectionProperties.html#afa6ea96eef4856627c8fef22aaa92d22',1,'com::sun::star::sdbc::JDBCConnectionProperties']]],
  ['javainitializationexception_12',['JavaInitializationException',['../exceptioncom_1_1sun_1_1star_1_1java_1_1JavaInitializationException.html',1,'com::sun::star::java']]],
  ['javainitializationexception_2eidl_13',['JavaInitializationException.idl',['../JavaInitializationException_8idl.html',1,'']]],
  ['javanotconfiguredexception_14',['JavaNotConfiguredException',['../exceptioncom_1_1sun_1_1star_1_1java_1_1JavaNotConfiguredException.html',1,'com::sun::star::java']]],
  ['javanotconfiguredexception_2eidl_15',['JavaNotConfiguredException.idl',['../JavaNotConfiguredException_8idl.html',1,'']]],
  ['javanotfoundexception_16',['JavaNotFoundException',['../exceptioncom_1_1sun_1_1star_1_1java_1_1JavaNotFoundException.html',1,'com::sun::star::java']]],
  ['javanotfoundexception_2eidl_17',['JavaNotFoundException.idl',['../JavaNotFoundException_8idl.html',1,'']]],
  ['javascript_18',['JavaScript',['../servicecom_1_1sun_1_1star_1_1script_1_1JavaScript.html',1,'com::sun::star::script']]],
  ['javascript_2eidl_19',['JavaScript.idl',['../JavaScript_8idl.html',1,'']]],
  ['javavirtualmachine_20',['JavaVirtualMachine',['../servicecom_1_1sun_1_1star_1_1java_1_1JavaVirtualMachine.html',1,'com::sun::star::java']]],
  ['javavirtualmachine_2eidl_21',['JavaVirtualMachine.idl',['../JavaVirtualMachine_8idl.html',1,'']]],
  ['javavmcreationfailureexception_22',['JavaVMCreationFailureException',['../exceptioncom_1_1sun_1_1star_1_1java_1_1JavaVMCreationFailureException.html',1,'com::sun::star::java']]],
  ['javavmcreationfailureexception_2eidl_23',['JavaVMCreationFailureException.idl',['../JavaVMCreationFailureException_8idl.html',1,'']]],
  ['jdbcconnectionproperties_24',['JDBCConnectionProperties',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1JDBCConnectionProperties.html',1,'com::sun::star::sdbc']]],
  ['jdbcconnectionproperties_2eidl_25',['JDBCConnectionProperties.idl',['../JDBCConnectionProperties_8idl.html',1,'']]],
  ['job_26',['Job',['../servicecom_1_1sun_1_1star_1_1task_1_1Job.html',1,'com::sun::star::task']]],
  ['job_2eidl_27',['Job.idl',['../Job_8idl.html',1,'']]],
  ['job_5faborted_28',['JOB_ABORTED',['../namespacecom_1_1sun_1_1star_1_1view.html#ad9b0afaffefc166344fd9575516b6626ad325c05e799526434df0446c1bfa1688',1,'com::sun::star::view']]],
  ['job_5fcompleted_29',['JOB_COMPLETED',['../namespacecom_1_1sun_1_1star_1_1view.html#ad9b0afaffefc166344fd9575516b6626a53c0e140b74182a89eea8096b1a51f16',1,'com::sun::star::view']]],
  ['job_5ffailed_30',['JOB_FAILED',['../namespacecom_1_1sun_1_1star_1_1view.html#ad9b0afaffefc166344fd9575516b6626abb2336dc05d82d17eb6f426a7d3242ae',1,'com::sun::star::view']]],
  ['job_5fspooled_31',['JOB_SPOOLED',['../namespacecom_1_1sun_1_1star_1_1view.html#ad9b0afaffefc166344fd9575516b6626adc1230e9b40f225f330421cb85f48e28',1,'com::sun::star::view']]],
  ['job_5fspooling_5ffailed_32',['JOB_SPOOLING_FAILED',['../namespacecom_1_1sun_1_1star_1_1view.html#ad9b0afaffefc166344fd9575516b6626a50a12e42e7a41dbad564813f1634f919',1,'com::sun::star::view']]],
  ['job_5fstarted_33',['JOB_STARTED',['../namespacecom_1_1sun_1_1star_1_1view.html#ad9b0afaffefc166344fd9575516b6626a5b34428f295a0d6b980f7d3d809d2c41',1,'com::sun::star::view']]],
  ['jobexecutor_34',['JobExecutor',['../servicecom_1_1sun_1_1star_1_1task_1_1JobExecutor.html',1,'com::sun::star::task']]],
  ['jobexecutor_2eidl_35',['JobExecutor.idl',['../JobExecutor_8idl.html',1,'']]],
  ['jobfinished_36',['jobFinished',['../interfacecom_1_1sun_1_1star_1_1task_1_1XJobListener.html#ab0c696543c8a005d3ca99c3785f845c4',1,'com::sun::star::task::XJobListener']]],
  ['jobmanager_37',['JobManager',['../servicecom_1_1sun_1_1star_1_1util_1_1JobManager.html',1,'com::sun::star::util']]],
  ['jobmanager_2eidl_38',['JobManager.idl',['../JobManager_8idl.html',1,'']]],
  ['jobname_39',['JobName',['../servicecom_1_1sun_1_1star_1_1view_1_1PrintOptions.html#a896deaa5ee4ac22bd1c8b5b8db37acf1',1,'com::sun::star::view::PrintOptions']]],
  ['jointype_40',['JoinType',['../structcom_1_1sun_1_1star_1_1rendering_1_1StrokeAttributes.html#af92b960dfbc8558928096e5b2076117c',1,'com::sun::star::rendering::StrokeAttributes']]],
  ['journal_41',['JOURNAL',['../namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a76c72d9a192bb0601aa1f27013fad3fd',1,'com::sun::star::text::BibliographyDataType::JOURNAL'],['../namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a76c72d9a192bb0601aa1f27013fad3fd',1,'com::sun::star::text::BibliographyDataField::JOURNAL']]],
  ['july_42',['JULY',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#aae7c7cc5b45c941aade847449d8355a2',1,'com::sun::star::i18n::Months']]],
  ['jumpedit_43',['JumpEdit',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1JumpEdit.html',1,'com::sun::star::text::textfield']]],
  ['jumpedit_2eidl_44',['JumpEdit.idl',['../JumpEdit_8idl.html',1,'']]],
  ['jumplist_45',['JumpList',['../servicecom_1_1sun_1_1star_1_1system_1_1windows_1_1JumpList.html',1,'com::sun::star::system::windows']]],
  ['jumplist_2eidl_46',['JumpList.idl',['../JumpList_8idl.html',1,'']]],
  ['jumplistitem_47',['JumpListItem',['../structcom_1_1sun_1_1star_1_1system_1_1windows_1_1JumpListItem.html',1,'com::sun::star::system::windows']]],
  ['jumplistitem_2eidl_48',['JumpListItem.idl',['../JumpListItem_8idl.html',1,'']]],
  ['jumpmark_49',['JumpMark',['../servicecom_1_1sun_1_1star_1_1document_1_1MediaDescriptor.html#a51b2490ba24ae76328c7637f379d8a69',1,'com::sun::star::document::MediaDescriptor']]],
  ['jumptoendofpage_50',['jumpToEndOfPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a476bbce6722fc804b8a67a6d7c4737cb',1,'com::sun::star::text::XPageCursor']]],
  ['jumptofirstpage_51',['jumpToFirstPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a35805ada8e62b68af3548c92d9239fc3',1,'com::sun::star::text::XPageCursor']]],
  ['jumptofurthest_52',['jumpToFurthest',['../interfacecom_1_1sun_1_1star_1_1io_1_1XMarkableStream.html#a0dba23daeafaaf331c5e8cabba583645',1,'com::sun::star::io::XMarkableStream']]],
  ['jumptolastpage_53',['jumpToLastPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a4f09bc833da25f1b6bdf50c27a707e2e',1,'com::sun::star::text::XPageCursor']]],
  ['jumptomark_54',['jumpToMark',['../interfacecom_1_1sun_1_1star_1_1io_1_1XMarkableStream.html#a5076d3fa091ca2a5616176f8e89e0e28',1,'com::sun::star::io::XMarkableStream']]],
  ['jumptonextpage_55',['jumpToNextPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a660dc90441fbc7a6af395112cfd11221',1,'com::sun::star::text::XPageCursor']]],
  ['jumptopage_56',['jumpToPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a909c766dbfe0e7e3e9c71d60f4ad4a36',1,'com::sun::star::text::XPageCursor']]],
  ['jumptopreviouspage_57',['jumpToPreviousPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#aaa932a448992229905f5d5c47e91c830',1,'com::sun::star::text::XPageCursor']]],
  ['jumptostartofpage_58',['jumpToStartOfPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a5c638004a9259895725d2cf920f3a587',1,'com::sun::star::text::XPageCursor']]],
  ['june_59',['JUNE',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#af314dbaf560683281ea205a8e8726e7e',1,'com::sun::star::i18n::Months']]],
  ['justify_60',['justify',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XTextLayout.html#afa630bace2ac1ee7acc044d589e99eb6',1,'com::sun::star::rendering::XTextLayout']]]
];
